@@ -3,9 +3,11 @@ module SciMLBaseMeasurementsExt
 using Measurements
 using SciMLBase: SciMLBase
 
-function SciMLBase.promote_u0(u0::AbstractArray{<:Measurements.Measurement},
-        p::AbstractArray{<:Measurements.Measurement}, t0)
-    u0
+function SciMLBase.promote_u0(
+        u0::AbstractArray{<:Measurements.Measurement},
+        p::AbstractArray{<:Measurements.Measurement}, t0
+    )
+    return u0
 end
 SciMLBase.promote_u0(u0, p::AbstractArray{<:Measurements.Measurement}, t0) = eltype(p).(u0)
 
